﻿using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;

namespace FeatureGuideCharp
{
    class _03_19_1
    {
        private String API_KEY = "your_api_key";
        private String API_URL = "https://sandbox.esignlive.com/api";
        public void Execute() {

            #region "information you need"
            string signerEmail = "signer1@mailinator.com";
            string documentId = "document1";
            string signatureId = "signer1_signature1";
            string fieldId = "signer1_signature1_textfield1";

            string updatedFieldValue = "updated value";
            #endregion

            #region "create a sample package"
            EslClient eslClient = new EslClient(API_KEY, API_URL);
            DocumentPackage pkg1 = PackageBuilder.NewPackageNamed("Example Package " + System.DateTime.Now)
               .WithSigner(SignerBuilder.NewSignerWithEmail(signerEmail)
                       .WithFirstName("John")
                       .WithLastName("Smith"))
               .WithDocument(DocumentBuilder.NewDocumentNamed("document 1")
                    .WithId(documentId)
                    .FromFile("your_file_path\\Test PDF.pdf")
                    .WithSignature(SignatureBuilder.SignatureFor(signerEmail)
                            .WithId(new SignatureId(signatureId))
                            .OnPage(0)
                            .AtPosition(100, 100)
                            .WithField(FieldBuilder.TextField().OnPage(0).AtPosition(100,300).WithId(fieldId))
                            )
               )
            .Build();
            PackageId createPackageOneStep = eslClient.CreateAndSendPackage(pkg1);
            Debug.WriteLine("package id: "+ createPackageOneStep);
            #endregion


            #region "update field value"
            string authToken = eslClient.AuthenticationTokenService.CreateSignerAuthenticationTokenForSingleUse(createPackageOneStep, signerEmail, null);
            string sessionToken = new AuthenticationService(API_URL.Substring(0, API_URL.LastIndexOf("/api"))).GetSessionIdForSignerAuthenticationToken(authToken);
            updateFieldOnBehalfOfSigner(API_URL, sessionToken, createPackageOneStep.Id, documentId, signatureId, fieldId, updatedFieldValue);
            #endregion


            #region "bulk send"
            eslClient.SignDocuments(createPackageOneStep, signerEmail);
            #endregion

        }

        private void updateFieldOnBehalfOfSigner(string API_URL, string sessionToken, string packageId, string documentId, string signatureId, string fieldId, string fieldValue) {
            using (var httpClient = new HttpClient(new HttpClientHandler { UseCookies = false }))
            {
                httpClient.DefaultRequestHeaders.Add("Accept", "application/json");
                httpClient.DefaultRequestHeaders.Add("Cookie", "ESIGNLIVE_SESSION_ID=" + sessionToken);

                string url = API_URL + "/packages/" + packageId + "/documents/" + documentId + "/approvals/" + signatureId + "/fields/" + fieldId;
                string requestContent = "{\"value\":\""+fieldValue+"\"}";
                var updateResponse =  httpClient.PostAsync(url, new StringContent(requestContent.ToString(), Encoding.UTF8, "application/json")).Result;
            }

        }



    }
}
